Security Advisories (9)
CPANSA-Mojolicious-2022-03 (2022-12-10)

Mojo::DOM did not correctly parse <script> tags.

CPANSA-Mojolicious-2021-02 (2021-06-01)

Small sessions could be used as part of a brute-force attack to decode the session secret.

CVE-2021-47208 (2021-03-16)

A bug in format detection can potentially be exploited for a DoS attack.

CVE-2018-25100 (2018-02-13)

Mojo::UserAgent::CookieJar leaks old cookies because of the missing host_only flag on empty domain.

CPANSA-Mojolicious-2015-01 (2015-02-02)

Directory traversal on Windows

CPANSA-Mojolicious-2018-03 (2018-05-19)

Mojo::UserAgent was not checking peer SSL certificates by default.

CPANSA-Mojolicious-2018-02 (2018-05-11)

GET requests with embedded backslashes can be used to access local files on Windows hosts

CPANSA-Mojolicious-2014-01 (2014-10-07)

Context sensitivity of method param could lead to parameter injection attacks.

CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

NAME

Mojo::UserAgent::Transactor - User Agent Transactor

SYNOPSIS

use Mojo::UserAgent::Transactor;

my $t  = Mojo::UserAgent::Transactor->new;
my $tx = $t->tx(GET => 'http://mojolicio.us');

DESCRIPTION

Mojo::UserAgent::Transactor is the transaction building and manipulation framework used by Mojo::UserAgent. Note that this module is EXPERIMENTAL and might change without warning!

METHODS

Mojo::UserAgent::Transactor inherits all methods from Mojo::Base and implements the following new ones.

form

my $tx = $t->form('http://kraih.com/foo' => {test => 123});
my $tx = $t->form(
  'http://kraih.com/foo',
  'UTF-8',
  {test => 123}
);
my $tx = $t->form(
  'http://kraih.com/foo',
  {test => 123},
  {Accept => '*/*'}
);
my $tx = $t->form(
  'http://kraih.com/foo',
  'UTF-8',
  {test => 123},
  {Accept => '*/*'}
);
my $tx = $t->form(
  'http://kraih.com/foo',
  {file => {file => '/foo/bar.txt'}}
);
my $tx = $t->form(
  'http://kraih.com/foo',
  {file => {content => 'lalala'}}
);
my $tx = $t->form(
  'http://kraih.com/foo',
  {myzip => {file => $asset, filename => 'foo.zip'}}
);

Versatile Mojo::Transaction::HTTP builder for form requests.

my $tx = $t->form('http://kraih.com/foo' => {test => 123});
$tx->res->body(sub { print $_[1] });
$ua->start($tx);

peer

my ($scheme, $host, $port) = $t->peer($tx);

Actual peer for transaction.

proxy_connect

my $tx = $t->proxy_connect($old);

Build Mojo::Transaction::HTTP proxy connect request for transaction.

redirect

my $tx = $t->redirect($old);

Build Mojo::Transaction::HTTP followup request for redirect response.

tx

my $tx = $t->tx(GET => 'mojolicio.us');
my $tx = $t->tx(POST => 'http://mojolicio.us');
my $tx = $t->tx(GET => 'http://kraih.com' => {Accept => '*/*'});
my $tx = $t->tx(
  POST => 'http://kraih.com' => {{Accept => '*/*'} => 'Hi!'
);

Versatile general purpose Mojo::Transaction::HTTP builder for requests.

# Streaming response
my $tx = $t->tx(GET => 'http://mojolicio.us');
$tx->res->body(sub { print $_[1] });
$ua->start($tx);

# Custom socket
my $tx = $t->tx(GET => 'http://mojolicio.us');
$tx->connection($socket);
$ua->start($tx);

websocket

my $tx = $t->websocket('ws://localhost:3000');

Versatile Mojo::Transaction::WebSocket builder for WebSocket handshake requests.

SEE ALSO

Mojolicious, Mojolicious::Guides, http://mojolicio.us.